@@ -1,41 +1,21 @@
 package SDLx::FPS;
 use strict;
+use warnings;
 use SDL::GFX::Framerate;
 use SDL::GFX::FPSManager;
 use Carp;
 our @ISA = qw(SDL::GFX::FPSManager);
 
 sub new {
-	my ( $class, @args ) = @_;
-	if ( ref $args[0] ) {
-		my %options = %{ $args[0] };
-		if ( @args > 1 ) {
-			Carp::cluck("Extra arguments are not taken when hash is specified");
-		}
-		for (
-			grep {
-				my $key = $_;
-				!grep $_ eq $key, qw/fps framecount rateticks lastticks rate/;
-			} keys %options
-			)
-		{
-			Carp::cluck("Unrecognized constructor hash key: $_");
-		}
-		@args = ( @options{qw/fps framecount rateticks lastticks rate/} );
-	} elsif ( @args > 4 ) {
-		Carp::cluck("Too many arguments given");
-	}
-	my $fps = $class->SDL::GFX::FPSManager::new(
-		map defined() ? $_ : 0,
-		@args[ 1 .. 4 ]
-	);
-	$fps->init;
-	$fps->set( $args[0] ) if defined $args[0];
-	$fps;
-}
+	my ( $class, %args ) = @_;
 
-sub init {
-	SDL::GFX::Framerate::init( $_[0] );
+	for ( grep { $_ ne 'fps' } keys %args ) {
+		Carp::cluck("Unrecognized constructor hash key: $_");
+	}
+	my $fps = $class->SDL::GFX::FPSManager::new( 0, 0, 0, 0 );
+	SDL::GFX::Framerate::init( $fps );
+	$fps->set( $args{fps} ) if defined $args{fps};
+	$fps;
 }
 
 sub set {
@@ -49,6 +29,7 @@ sub get {
 sub delay {
 	SDL::GFX::Framerate::delay( $_[0] );
 }
+
 1;
 
 __END__
@@ -77,21 +58,10 @@ Use it to delay the main loop to keep it at a specified framerate.
 
 =head2 new
 
- my $fps = SDLx::FPS->new(
-     fps => 30, framecount => 0, rateticks => 0, lastticks => 0, rate => 0
- );
+ my $fps = SDLx::FPS->new( fps => 30 );
 
-The constructor takes a hash with 5 possible arguments as shown.
 No arguments are required, if no C<fps> is specified, the default FPS is 30.
 
-C<framecount>, C<rateticks>, C<lastticks> and C<rate> correspond to the 4 arguments given to C<SDL::GFX::FPSManager->new>.
-
-=head2 init
-
-Same as C<SDL::GFX::Framerate::init>.
-Initialize the framerate manager, set default framerate of 30Hz and reset delay interpolation.
-You don't need to call this; C<new> does it for you.
-
 =head2 set
 
  $fps->set($new_framerate);
